KeyboardKeyConfig class
Individual key layout parameter.
Constructors
- KeyboardKeyConfig({required String label, String? labelEn, required KeyboardKeyType type, String value = '', int flex = 1})
-
const
Properties
- flex → int
-
Vertical size ratio within its column (e.g. flex 2 for taller keys like "Xong")
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- label → String
-
Localized Vietnamese or general label
final
- labelEn → String?
-
Optional English label (e.g. "Xóa" -> "Clear", "Xong" -> "Done")
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → KeyboardKeyType
-
Type of key representing its business logic
final
- value → String
-
The character string value to insert when tap triggers
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited