KeyboardTheme class
Theme configurations for the custom stock keyboard. Supports customization for standard keys, action keys, special keys, background styling, and quick suggestions.
Constructors
- KeyboardTheme({required Color backgroundColor, required Color commonKeyColor, required Color specialKeyColor, required Color actionKeyColor, required Color textColor, required Color actionTextColor, required Color suggestionBackgroundColor, required Color suggestionChipColor, required Color suggestionTextColor, required Color activeSuggestionChipColor, required Color activeSuggestionTextColor, double keyFontSize = 25.0, double specialKeyFontSize = 15.0})
-
const
- KeyboardTheme.dark({double keyFontSize = 25.0, double specialKeyFontSize = 15.0})
-
Premium dark mode theme for high visual excellence.
factory
- KeyboardTheme.light({double keyFontSize = 25.0, double specialKeyFontSize = 15.0})
-
Premium light mode theme, mapping colors from Vietnamese financial systems.
factory
Properties
- actionKeyColor → Color
-
final
- actionTextColor → Color
-
final
- activeSuggestionChipColor → Color
-
final
- activeSuggestionTextColor → Color
-
final
- backgroundColor → Color
-
final
- commonKeyColor → Color
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- keyFontSize → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- specialKeyColor → Color
-
final
- specialKeyFontSize → double
-
final
- suggestionBackgroundColor → Color
-
final
- suggestionChipColor → Color
-
final
- suggestionTextColor → Color
-
final
- textColor → Color
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited